@@ -3,6 +3,7 @@ import tg
 from tg.i18n import lazy_ugettext as l_
 from tgext.ajaxforms import ajaxloaded
 from tgext.pluggable import plug_url
+from smallpress.lib.validators import NaiveDateTimeValidator
 
 class SpinnerIcon(object):
     @property
@@ -29,7 +30,7 @@ if tg.config.get('prefer_toscawidgets2', False):
                          placeholder=l_('tags, comma separated'))
         content = TextArea(label=None, key='content', name='content', id="article_content",
                            validator=UnicodeString(not_empty=True, outputEncoding=None))
-        publish_date = TextField(label='Publish Date')
+        publish_date = TextField(label='Publish Date', validator=NaiveDateTimeValidator(not_empty=True))
 
     @ajaxloaded
     class UploadForm(ListForm):
@@ -68,7 +69,7 @@ else:
                              attrs=dict(placeholder=l_('tags, comma separated')))
             content = TextArea(suppress_label=True, validator=UnicodeString(not_empty=True),
                                attrs=dict(id='article_content'))
-            publish_date = TextField(label_text='Publish Date')
+            publish_date = TextField(label_text='Publish Date', validator=NaiveDateTimeValidator(not_empty=True))
 
     @ajaxloaded
     class UploadForm(ListForm):
